structure RandomAI :> PLAYER = struct

    open AIGame
    type player = Types.move * Time.time -> Types.move

    fun getName() = "RandomAI"

    val date = Date.fromTimeLocal(Time.now())
    val seedset = Random.rand(Date.second(date), Date.minute(date))

    fun getNextMove (boardSize: int ref)
                    (game: game ref)
                    (color: piece ref)
                    (mv: Types.move, timeLeft: Time.time): Types.move =
      let
        val center = !boardSize div 2
        val random = Random.randRange(0,!boardSize - 1)
        val mv =
          case mv of
             Types.Move(x,y) => (x,y)
           | Types.Start     => (~1, ~1)
           |     _     => raise Fail "incorrect move!"


        fun otherMoves() =
          let
            val {gameBoard, moveList,...} = !game
            val x = random(seedset)
            val y = random(seedset)
          in
            if (validMove((x, y), gameBoard, moveList))
            then (x,y)
            else otherMoves()
          end

        fun updateGame(c:coordinate) =
          let
            val g = step(!game,c)
          in
            (game := g;
             Types.Move(c))
          end
      in
        (* if last move was (~1,~1) then put piece in center *)
        (* else random :)*)
        updateGame(if (mv = (~1,~1)) then (center,center) 
                   else (updateGame(mv); otherMoves()))
      end

    fun createPlayer (p:Types.color)
                     (boardSize:int)
                     (timeLeft:Time.time) =
      let
        val game = ref (newGame(boardSize))
        val boardSize = ref boardSize
        val color = ref (case p of Types.BLACK => BLACK | _ => WHITE)
      in
        getNextMove (boardSize) (game) (color)
      end
end
